@@ -43,6 +43,10 @@ def tags(q):
 def api_key(api_key):
   return str(api_key) if api_key else ""
 
+def validate_filter(filter_id):
+  # is it always an number?
+  return str(filter_id) if filter_id else ""
+
 def sort_format(sf):
   if sf not in sort.methods:
     raise AttributeError(sf)
@@ -62,14 +66,14 @@ def format_params(params):
   p = {}
 
   for key, value in params.items():
-    if key == "key":
-      if value:
-        p["key"] = value
-    elif key == "q":
-      p["q"] = ",".join(value) if value else "*"
-    elif key in ("faves", "upvotes", "uploads", "watched"):
+    if key == "key" or key == "filter_id":
       if value:
         p[key] = value
+    elif key in ("faves", "upvotes", "uploads", "watched"):
+      if value and params["key"]:
+        p[key] = value
+    elif key == "q":
+      p["q"] = ",".join(value) if value else "*"
     else:
       p[key] = value
 
